from settings import *  # noqa

INSTALLED_APPS.append('content_gfk')

ROOT_URLCONF = 'content_gfk.urls'
